Module reader

Module reader 

Functions

process_spreadsheet_async
Output the result set with deferred row saving and optional output reference
process_spreadsheet_core
Output the result set with captured rows (up to the maximum allowed) directly. with optional asynchronous row save method and output reference
process_spreadsheet_direct
Output the result set with captured rows (up to the maximum allowed) directly. This is now synchronous and calls the asynchronous function using a runtime.
process_spreadsheet_immediate
Output the result set with captured rows (up to the maximum allowed) immediately. Use this in an async function using the tokio runtime if you direct results without a save callback
read_csv_core
Process a CSV/TSV file asynchronously with an optional row save method and output reference (file or database table reference)
read_single_worksheet
Read a single worksheet from a workbook in immediate (sync) or asycnhronous modes
read_workbook_core
Parse spreadsheets with an optional callback method to save rows asynchronously and an optional output reference that may be a file name or database identifier
read_workbook_sheet_info
render_spreadsheet_coreDeprecated
render_spreadsheet_directDeprecated