spreadsheet_to_json::options

Struct OptionSet

pub struct OptionSet {
    pub sheet: Option<String>,
    pub index: u32,
    pub path: Option<String>,
    pub rows: RowOptionSet,
    pub jsonl: bool,
    pub max: Option<u32>,
    pub omit_header: bool,
    pub header_row: u8,
    pub read_mode: ReadMode,
    pub field_mode: FieldNameMode,
}
Core options with nested row options

Fields

sheet: Option<String>index: u32path: Option<String>rows: RowOptionSetjsonl: boolmax: Option<u32>omit_header: boolheader_row: u8read_mode: ReadModefield_mode: FieldNameMode

Implementations

Source

impl OptionSet

pub fn new(path_str: &str) -> Self

Instantiates a new option set with a path string for file operations.

pub fn sheet_name(&mut self, name: String) -> &mut Self

Sets the sheet name for the operation.

pub fn sheet_index(&mut self, index: u32) -> &mut Self

Sets the sheet index.

pub fn json_lines(&mut self) -> &mut Self

Sets JSON Lines mode to true.

pub fn omit_header(&mut self) -> &mut Self

Omits the header when reading.

pub fn header_row(&mut self, row: u8) -> &mut Self

Sets the header row index

pub fn max_row_count(&mut self, max: u32) -> &mut Self

Sets the maximum number of rows to read.

pub fn read_mode_async(&mut self) -> &mut Self

Sets the read mode to asynchronous.

pub fn field_name_mode( &mut self, system: &str, override_header: bool, ) -> &mut Self

Sets the column key naming convetion

pub fn row_mode(&self) -> String

pub fn header_mode(&self) -> String

pub fn to_json(&self) -> Value

pub fn to_lines(&self) -> Vec<String>

pub fn header_row_index(&self) -> usize

header row index as usize

pub fn max_rows(&self) -> usize

set the maximum of rows to be output synchronously

pub fn columns(&self) -> Vec<Column>

future development with advanced column options

pub fn read_mode(&self) -> ReadMode

cloned read mode

pub fn is_async(&self) -> bool

Needs full data set to processed later

pub fn capture_rows(&self) -> bool