spreadsheet_to_json

Module reader

Functions

  • Output the result set with deferred row saving and optional output reference
  • Output the result set with captured rows (up to the maximum allowed) directly. with optional asynchronous row save method and output reference
  • Output the result set with captured rows (up to the maximum allowed) directly. This is now synchronous and calls the asynchronous function using a runtime.
  • Output the result set with captured rows (up to the maximum allowed) immediately. Use this in an async function using the tokio runtime if you direct results without a save callback
  • Process a CSV/TSV file asynchronously with an optional row save method and output reference (file or database table reference)
  • Read a single worksheet from a workbook in immediate (sync) or asycnhronous modes
  • Parse spreadsheets with an optional callback method to save rows asynchronously and an optional output reference that may be a file name or database identifier