Functions
- Process a CSV/TSV file asynchronously with an optional row save method amd output reference (file or database table reference)
- Parse spreadsheets with an optional callback method to save rows asynchronously and an optional output reference that may be a file name or database identifier
- Output the result set with captured rows (up to the maximum allowed) directly. This is still asynchronous as it’s a wrapper for a function accepting multithreaded async callbacks