spreadsheet_to_json

Module reader

Functions

  • process CSV file asynchronously with optional row save method amd output reference (file or database table reference)
  • Supports asynchronous handling of large spreadsheets
  • Output the result set with captured rows (up to the maximum allowed) directly this is still asynchronous as it’s a wrapper for a function accepting multithreaded async callbacks